@@ -33,6 +33,7 @@ function h2i_usage
 	printf "  -a, --author=AUTHOR\t\tset full author name\n"
 	printf "  -c, --copyright=COPYRIGHT\tset copyright holder\n"
 	printf "  -b, --bugreport=BUGREPORT\tset bug report address\n"
+	printf "  -g, --generate=VERSION\tgenerate version.texi\n"
 	printf "  -h, --help\t\t\tshows a help message\n"
 	printf "  -v, --version\t\t\tshows the program version\n"
 	printf "\n"
@@ -46,8 +47,8 @@ function h2i_version
 	exit 0
 }
 
-TEMP=$(getopt -o "d:n:a:c:b:hv" \
-	      -l "dircategory:,programname:,author:,copyright:,bugreport:,help,version" -n "$H2I" -- "$@")
+TEMP=$(getopt -o "d:n:a:c:b:g:hv" \
+	      -l "dircategory:,programname:,author:,copyright:,bugreport:,generate:,help,version" -n "$H2I" -- "$@")
 eval set -- "$TEMP"
 while [[ -n "$1" ]]
 do
@@ -57,6 +58,7 @@ do
 		-"a" | --"author") H2I_INFO_AUTHOR="$2"; shift 2;;
 		-"c" | --"copyright") H2I_INFO_COPYRIGHT="$2"; shift 2;;
 		-"b" | --"bugreport") H2I_INFO_BUGREPORT="$2"; shift 2;;
+		-"g" | --"generate") H2I_INFO_VERSION="$2"; shift 2;;
 		-"h" | --"help") h2i_usage; shift;;
 		-"v" | --"version") h2i_version; shift;;
 		--) shift; break;;
@@ -239,6 +241,7 @@ then H2I_INFO_BUGREPORT=$(h2i_bugreport "$H2I_OUTPUT")
 fi
 
 # generate the texi file
+printf "Creating ${H2I_INFO_PROGRAM_NAME}.texi in current directory..."
 cat > "${H2I_INFO_PROGRAM_NAME}.texi" <<EOF
 \input texinfo	@c -*-texinfo-*-
 @comment It was generated by help2info $H2I_VERSION.
@@ -259,7 +262,7 @@ Copyright @copyright{} $H2I_INFO_YEAR $H2I_INFO_COPYRIGHT
 Permission is granted to copy, distribute, and/or modify this document
 under the terms of the GNU Free Documentation License, Version 1.2 or
 any later version published by the Free Software Foundation; with no
-Invariant Sections, with the Front-Cove Texts bein ``A Manual,''
+Invariant Sections, with the Front-Cove Texts being ``A Manual,''
 and with the Back-Cover Texts as in (a) below. A copy of the
 license is included in the section entitled ``GNU Free Documentation
 License.''
@@ -340,6 +343,29 @@ Email bug reports to @email{$H2I_INFO_BUGREPORT}. Be sure to include the word @d
 
 @bye
 EOF
+if [[ $? == 0 ]]
+then echo "done"
+else echo "error"
+fi
 
 #copy the fdl.texi file
+printf "Copying fdl.texi to current directory..."
 cp "$H2I_DATADIR/fdl.texi" .
+if [[ $? == 0 ]]
+then echo "done"
+else echo "error"
+fi
+
+if [[ -n $H2I_INFO_VERSION ]]
+then
+H2I_INFO_UPDATED=$(date '+%-e %B %Y')
+printf "Creating version.texi in current directory..."
+cat > "version.texi" <<EOF
+@set UPDATED $H2I_INFO_UPDATED
+@set VERSION $H2I_INFO_VERSION
+EOF
+if [[ $? == 0 ]]
+then echo "done"
+else echo "error"
+fi
+fi
